---
title: Entry 3
date: 2023-01-01
tags: [tag1, tag2, tag4]
brief: third entry in category two with tags one, two, four
---

# Purpose

The purpose of this file is to show off the index page functionality of `alloypress`.